%define anolis_release 1

%global golang_arches   x86_64 aarch64 loongarch64
%global gopath          %{_datadir}/gocode
%global _spectemplatedir %{_datadir}/rpmdevtools/anolis
%global _docdir_fmt     %{name}

ExclusiveArch: %{golang_arches}

Name:      go-rpm-macros
Version:   3.6.0
Release:   %{anolis_release}%{?dist}
Summary:   Build-stage rpm automation for Go packages
License:   GPL-3.0-or-later
URL:       https://pagure.io/%{name}
Source:    https://pagure.io/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Patch1:    1001-modify-for-anolis.patch

Requires:  go-srpm-macros = %{version}-%{release} go-filesystem  = %{version}-%{release}
Requires:  golist

%ifarch %{golang_arches}
Requires:  golang
Provides:  compiler(golang) compiler(go-compiler) = 2
Obsoletes: go-compilers-golang-compiler < %{version}-%{release}
%endif

%description
The %{name} provides build-stage rpm automation to simplify the creation of
Go language packages. The %{name} project provides files needed to automate
Go rpm packaging.

%package -n go-filesystem
Summary:   Directories used by Go packages
License:   LicenseRef-Fedora-Public-Domain

%description -n go-filesystem
This package contains the basic directory layout used by Go packages.

%package -n go-rpm-templates
Summary:   RPM spec templates for Go packages
License:   MIT
# go-rpm-macros only exists on some architectures, so this package cannot be noarch
Requires:  %{name} = %{version}-%{release}

%description -n go-rpm-templates
This package contains the template of the RPM specification file that records
how to use the macros provided by %{name} to create a Go package.

%package -n go-srpm-macros
Summary:   Source-stage rpm automation for Go packages
BuildArch: noarch
Requires:  system-rpm-config

%description -n go-srpm-macros
This package provides SRPM-stage rpm automation to simplify the creation of Go
language packages. The go-srpm-macros will pull in for Go packages only.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1
%writevars -f rpm/macros.d/macros.go-srpm golang_arches gopath
for template in templates/rpm/*\.spec ; do
  target=$(echo "${template}" | sed "s|^\(.*\)\.spec$|\1-bare.spec|g")
  grep -v '^#' "${template}" > "${target}"
  touch -r "${template}" "${target}"
done

%install
install -m 0755 -vd   %{buildroot}%{rpmmacrodir}

install -m 0755 -vd   %{buildroot}%{_rpmluadir}/anolis/srpm
install -m 0644 -vp   rpm/lua/srpm/*lua \
                      %{buildroot}%{_rpmluadir}/anolis/srpm

install -m 0755 -vd   %{buildroot}%{gopath}/src
install -m 0755 -vd   %{buildroot}%{_spectemplatedir}
install -m 0644 -vp   templates/rpm/*spec \
                      %{buildroot}%{_spectemplatedir}
install -m 0755 -vd   %{buildroot}%{_bindir}
install -m 0755 bin/* %{buildroot}%{_bindir}

install -m 0644 -vp   rpm/macros.d/macros.go-*rpm* \
                      %{buildroot}%{rpmmacrodir}
install -m 0755 -vd   %{buildroot}%{_rpmluadir}/anolis/rpm
install -m 0644 -vp   rpm/lua/rpm/*lua \
                      %{buildroot}%{_rpmluadir}/anolis/rpm
install -m 0755 -vd   %{buildroot}%{_rpmconfigdir}/fileattrs
install -m 0644 -vp   rpm/fileattrs/*.attr \
                      %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0755 -vp   rpm/*\.{prov,deps} \
                      %{buildroot}%{_rpmconfigdir}/

%ifarch %{golang_arches}
install -m 0644 -vp   rpm/macros.d/macros.go-compilers-golang{,-pie} \
                      %{buildroot}%{_rpmconfigdir}/macros.d/
%endif

%files
%license LICENSE.txt
%{_bindir}/*
%{_rpmconfigdir}/fileattrs/*.attr
%{_rpmconfigdir}/*.prov
%{_rpmconfigdir}/*.deps
%{_rpmmacrodir}/macros.go-rpm*
%{_rpmmacrodir}/macros.go-compiler*
%{_rpmluadir}/anolis/rpm/*.lua

%files -n go-filesystem
%dir %{gopath}
%dir %{gopath}/src

%files -n go-rpm-templates
%license LICENSE-templates.txt
%dir %{dirname:%{_spectemplatedir}}
%dir %{_spectemplatedir}
%{_spectemplatedir}/*.spec

%files -n go-srpm-macros
%license LICENSE.txt
%{_rpmmacrodir}/macros.go-srpm
%{_rpmluadir}/anolis/srpm/*.lua

%files doc
%doc README.md

%changelog
* Wed Feb 26 2025 wangzhe <wanglan.wz@alibaba-inc.com> - 3.6.0-1
- Refer to CentOS Stream go-rpm-macros-3.6.0-4 (tdawson@redhat.com)

* Wed Sep 13 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 3.0.15-4
- add loong64 support for go-rpm-macros

* Wed Apr 12 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 3.0.15-3
- Refact spec

* Fri Mar 31 2023 happy_orange <songnannan@linux.alibaba.com> - 3.0.15-2
- remove golist in requires

* Thu Mar 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> 3.0.15-1
- init from upstream 3.0.15.
